mouse library
A simple, low-dependency and cross-platform mouse control library for Dart.
This package provides primitive mouse control functionality for desktop platforms. It supports both Windows and macOS, allowing you to programmatically control mouse movements and clicks.
Enums
- MouseButton
- The mouse button to use.
Functions
-
click(
) → void - Click the left mouse button.
-
getPosition(
) → Point< double> - Get the current mouse cursor position.
-
mouseDown(
MouseButton button) → void - Press down a mouse button.
-
mouseUp(
MouseButton button) → void - Release a mouse button.
-
moveTo(
Point< double> position) → void - Move the mouse cursor to a specific position.
-
rightClick(
) → void - Click the right mouse button.